summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasitem_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasitem_imp.h')
-rw-r--r--kjsembed/qtbindings/qcanvasitem_imp.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kjsembed/qtbindings/qcanvasitem_imp.h b/kjsembed/qtbindings/qcanvasitem_imp.h
index 5af88785..8951eda0 100644
--- a/kjsembed/qtbindings/qcanvasitem_imp.h
+++ b/kjsembed/qtbindings/qcanvasitem_imp.h
@@ -17,7 +17,7 @@ class QCanvasItem;
namespace KJSEmbed {
/**
* Wrapper class for QCanvasItem methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -90,7 +90,7 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static QCanvasItem *toQCanvasItem( KJS::Object &object );
+ static TQCanvasItem *toQCanvasItem( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -158,7 +158,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- QCanvasItem *instance; // Temp
+ TQCanvasItem *instance; // Temp
int id;
bool cons;
};
@@ -17,7 +17,7 @@ class QCanvasItem;
namespace KJSEmbed {
/**
- * Wrapper class for QCanvasItem methods.
+ * Wrapper class for TQCanvasItem methods.
*
* @author Richard Moore, rich@kde.org